@@ -1,21 +1,21 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.019-2-g475ab86
-# ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.020-8-g77915d9
+# ABSTRACT: Generate a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use Moose;
-use MooseX::Types;
-use MooseX::Types::Moose 'ArrayRef';
 with
     'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::FileGatherer',
     'Dist::Zilla::Role::BuildPL',
     'Dist::Zilla::Role::PrereqSource';
 
+use MooseX::Types;
+use MooseX::Types::Moose 'ArrayRef';
 use Dist::Zilla::Plugin::ModuleBuild;
 use Dist::Zilla::Plugin::ModuleBuildTiny;
 use Moose::Util 'find_meta';
@@ -235,27 +235,36 @@ FALLBACK1
     . <<'FALLBACK2'
 );
 
-my @missing = grep {
-    ! eval "require $_; $_->VERSION($configure_requires{$_}); 1"
+my %errors = map {
+    eval "require $_; $_->VERSION($configure_requires{$_}); 1";
+    $_ => $@,
 } keys %configure_requires;
 
-if (not @missing)
+if (!grep { $_ } values %errors)
 {
 FALLBACK2
-    . <<"FALLBACK3"
-$mbt_content}
+    . $mbt_content . "}\n"
+    . <<'FALLBACK3'
 else
 {
-    if (not \$ENV{PERL_MB_FALLBACK_SILENCE_WARNING})
+    if (not $ENV{PERL_MB_FALLBACK_SILENCE_WARNING})
     {
-        warn <<'EOW';
-$message
+        warn <<'EOW'
+FALLBACK3
+    . $message . <<'FALLBACK4'
+
+
+Errors from configure prereqs:
 EOW
+        . do {
+            require Data::Dumper; Data::Dumper->new([ \%errors ])->Indent(2)->Terse(1)->Sortkeys(1)->Dump;
+        };
+
         sleep 10 if -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
     }
 
-$mb_content}
-FALLBACK3
+FALLBACK4
+    .  $mb_content . "}\n"
     );
 
     return;
@@ -353,14 +362,6 @@ __PACKAGE__->meta->make_immutable;
 #pod the minimum version of L<Module::Build::Tiny> to depend on (in
 #pod C<configure_requires> as well as a C<use> assertion in F<Build.PL>).
 #pod
-#pod =head1 SUPPORT
-#pod
-#pod =for stopwords irc
-#pod
-#pod Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-ModuleBuildTiny-Fallback>
-#pod (or L<bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org>).
-#pod I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-#pod
 #pod =head1 ACKNOWLEDGEMENTS
 #pod
 #pod =for stopwords Rabbitson ribasushi mst
@@ -382,11 +383,11 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
+Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Generate a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -471,14 +472,6 @@ Passed to L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny> as C<version
 the minimum version of L<Module::Build::Tiny> to depend on (in
 C<configure_requires> as well as a C<use> assertion in F<Build.PL>).
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-ModuleBuildTiny-Fallback>
-(or L<bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 =for stopwords Rabbitson ribasushi mst
@@ -503,6 +496,19 @@ L<Dist::Zilla::Plugin::ModuleBuild>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-ModuleBuildTiny-Fallback>
+(or L<bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-ModuleBuildTiny-Fallback@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
